==> jersey-server-1.1.4.1-sources.jar: com/sun/jersey/spi/container/servlet/WebConfig.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://jersey.dev.java.net/CDDL+GPL.html
 * or jersey/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at jersey/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.jersey.spi.container.servlet;

import com.sun.jersey.api.core.ResourceConfig;
import java.util.Enumeration;
import java.util.Map;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;

/**
 * The Web configuration for accessing initialization parameters of a Web
 * component and the {@link ServletContext}.
 * 
 * @author Paul.Sandoz@Sun.Com
 */
public interface WebConfig {

    /**
     * Get the name of the Web component.
     *
     * @return the name of the Web component.
     */
    String getName();

    /**
     * Get an initialization parameter.
     * 
     * @param name the parameter name.
     * @return the parameter value, or null if the parameter is not present.
     */
    String getInitParameter(String name);

    /**
     * Get the enumeration of initialization parameter names.
     * 
     * @return the enumeration of initialization parameter names.
     */
    Enumeration getInitParameterNames();

    /**
     * Get the {@link ServletContext}.
     * 
     * @return the {@link ServletContext}.
     */
    ServletContext getServletContext();

    /**
     * Get the default {@link ResourceConfig}.
     * 
     * @param props the map of properties.
     * 
     * @return the default {@link ResourceConfig}.
     * @throws javax.servlet.ServletException
     */
    ResourceConfig getDefaultResourceConfig(Map<String, Object> props) throws ServletException;
}

==> jersey-server-1.2-sources.jar: com/sun/jersey/spi/container/servlet/WebConfig.java <==
/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://jersey.dev.java.net/CDDL+GPL.html
 * or jersey/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at jersey/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.jersey.spi.container.servlet;

import com.sun.jersey.api.core.ResourceConfig;
import java.util.Enumeration;
import java.util.Map;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;

/**
 * The Web configuration for accessing initialization parameters of a Web
 * component and the {@link ServletContext}.
 * 
 * @author Paul.Sandoz@Sun.Com
 */
public interface WebConfig {

    /**
     * The web configuration type.
     */
    public static enum ConfigType {
        /**
         * A configuration type of servlet configuration.
         */
        ServletConfig,
        /**
         * A configuration type of filter configuration.
         */
        FilterConfig
    };
    
    /**
     * Get the configuration type of this config.
     * 
     * @return the configuration type.
     */
    ConfigType getConfigType();

    /**
     * Get the name of the Web component.
     *
     * @return the name of the Web component.
     */
    String getName();

    /**
     * Get an initialization parameter.
     * 
     * @param name the parameter name.
     * @return the parameter value, or null if the parameter is not present.
     */
    String getInitParameter(String name);

    /**
     * Get the enumeration of initialization parameter names.
     * 
     * @return the enumeration of initialization parameter names.
     */
    Enumeration getInitParameterNames();

    /**
     * Get the {@link ServletContext}.
     * 
     * @return the {@link ServletContext}.
     */
    ServletContext getServletContext();

    /**
     * Get the default {@link ResourceConfig}.
     * 
     * @param props the map of properties.
     * 
     * @return the default {@link ResourceConfig}.
     * @throws javax.servlet.ServletException
     */
    ResourceConfig getDefaultResourceConfig(Map<String, Object> props) throws ServletException;
}
